Re-exports
pub use prefix_covector::OffsetCovector;pub use prefix_covector::PrefixCovector;pub use prefix_covector::SparseCovector;pub use witness::PublicInputs;
Modules
Structs
- Noir
Proof - Noir
Proof Scheme - A scheme for proving a Noir program.
- Prover
- R1CS
- Represents a R1CS constraint system.
- Verifier
- Whir
R1CS Proof - Whir
R1CS Scheme
Enums
- Format
- The different formats that are supported when parsing the initial witness values
- Input
Value - This is what all formats eventually transform into For example, a toml file will parse into TomlTypes and those TomlTypes will be mapped to Value
Functions
- register_
ntt - Register provekit’s custom implementations in whir’s global registries.
Type Aliases
- Field
Element - Input
Map - A map from the fields in an TOML/JSON file which correspond to some ABI to their values
- Noir
Element - Transcript
Sponge - SHA-256 based transcript sponge for Fiat-Shamir.
- Whir
Config - Whir
Domain Separator - Type alias for the whir domain separator used in provekit’s outer protocol.
- Whir
Proof - Type alias for the whir proof.
- Whir
Prover State - Type alias for the whir prover transcript state.
- Whir
ZkConfig