Module sumcheck

Module sumcheck 

Functions

calculate_eq
Calculates eq(r, alpha)
calculate_evaluations_over_boolean_hypercube_for_eq
List of evaluations for eq(r, x) over the boolean hypercube, truncated to num_entries elements. When num_entries < 2^r.len(), avoids allocating the full hypercube.
calculate_external_row_of_r1cs_matrices
Calculates a random row of R1CS matrix extension. Made possible due to sparseness.
calculate_witness_bounds
Given a path to JSON file with sparce matrices and a witness, calculates matrix-vector multiplication and returns them
eval_cubic_poly
Evaluates a cubic polynomial on a value
multiply_transposed_by_eq_alpha
Multiply pre-transposed R1CS matrices by eq(alpha, ·) to compute the external row.
sumcheck_fold_map_reduce
Compute the sum of a vector valued function over the boolean hypercube in the leading variable.
transpose_r1cs_matrices
Transpose all three R1CS matrices in parallel.