Crate provekit_common

Crate provekit_common 

Re-exports

pub use prefix_covector::OffsetCovector;
pub use prefix_covector::PrefixCovector;
pub use prefix_covector::SparseCovector;
pub use witness::PublicInputs;

Modules

file
prefix_covector
sparse_matrix
utils
witness

Structs

NoirProof
NoirProofScheme
A scheme for proving a Noir program.
Prover
R1CS
Represents a R1CS constraint system.
Verifier
WhirR1CSProof
WhirR1CSScheme

Enums

Format
The different formats that are supported when parsing the initial witness values
InputValue
This is what all formats eventually transform into For example, a toml file will parse into TomlTypes and those TomlTypes will be mapped to Value

Functions

register_ntt
Register provekit’s custom implementations in whir’s global registries.

Type Aliases

FieldElement
InputMap
A map from the fields in an TOML/JSON file which correspond to some ABI to their values
NoirElement
TranscriptSponge
SHA-256 based transcript sponge for Fiat-Shamir.
WhirConfig
WhirDomainSeparator
Type alias for the whir domain separator used in provekit’s outer protocol.
WhirProof
Type alias for the whir proof.
WhirProverState
Type alias for the whir prover transcript state.
WhirZkConfig