pub struct SparseMatrix {
pub num_rows: usize,
pub num_cols: usize,
/* private fields */
}Expand description
A sparse matrix with interned field elements.
Uses delta encoding for column indices during serialization to reduce size. Within each row, the first column index is stored as absolute, and subsequent columns are stored as deltas from the previous column.
Fields
num_rows: usizeThe number of rows in the matrix.
num_cols: usizeThe number of columns in the matrix.
Implementations
Sourceimpl SparseMatrix
impl SparseMatrix
pub fn new(rows: usize, cols: usize) -> Self
pub const fn hydrate<'a>( &'a self, interner: &'a Interner, ) -> HydratedSparseMatrix<'a>
pub fn num_entries(&self) -> usize
pub fn delta_encoding_stats(&self) -> DeltaEncodingStats
pub fn grow(&mut self, rows: usize, cols: usize)
Sourcepub fn set(&mut self, row: usize, col: usize, value: InternedFieldElement)
pub fn set(&mut self, row: usize, col: usize, value: InternedFieldElement)
Set the value at the given row and column.
Sourcepub fn iter_row(
&self,
row: usize,
) -> impl Iterator<Item = (usize, InternedFieldElement)> + use<'_>
pub fn iter_row( &self, row: usize, ) -> impl Iterator<Item = (usize, InternedFieldElement)> + use<'_>
Iterate over the non-default entries of a row of the matrix.
Sourcepub fn iter(
&self,
) -> impl Iterator<Item = ((usize, usize), InternedFieldElement)> + use<'_>
pub fn iter( &self, ) -> impl Iterator<Item = ((usize, usize), InternedFieldElement)> + use<'_>
Iterate over the non-default entries of the matrix.
Sourcepub fn transpose(&self) -> SparseMatrix
pub fn transpose(&self) -> SparseMatrix
Transpose the matrix, swapping rows and columns.
Returns a new SparseMatrix where entry (i, j) in the original
becomes (j, i) in the result. The interned values are preserved
and remain valid for the same Interner.